/*
 * Copyright (c) 2007 Alexey Vatchenko <av@bsdua.org>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef _CDMA_CDMA_H_
#define _CDMA_CDMA_H_
#include <sys/types.h>

/*
 * Time parsing and processing
 */
struct cdma_time {
	int year;
	int month;
	int day;
	int hour;
	int min;
	int sec;
	char wday[4];	/* 3-letter abbr. */
	char tz[7];	/* e.g. GMT+12 */
};

/*
 * PIN code statuses
 */
#define PIN_ENABLED		1
#define PIN_NEEDED		2
#define PIN_PUK			4

/*
 * SMS
 */
struct cdma_sms {
	struct cdma_time when;	/* NOTE, wday must be ignored */
	char from[20];	/* at least for +38092XXXYYZZ */
	char msg[161];
};

typedef void (*cdma_sms_callback)(const char *index, struct cdma_sms *sms);

/*
 * Phonebook
 */
typedef void (*cdma_pb_callback)(const char *index, const char *phone,
    const char *name);

struct cdma_dev;

/*
 * Main context
 */
struct cdma {
	char *buf;
	size_t bufsz;
	int fd;
	struct cdma_dev *dev;
};

enum cdma_limit {
	CDMA_LIMIT_PHONE,
	CDMA_LIMIT_CONTACT
};

#endif /* !_CDMA_CDMA_H_ */
