/*
 * Copyright (c) 2007 Alexey Vatchenko <av@bsdua.org>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef _CDMA_DEV_H_
#define _CDMA_DEV_H_

#include <sys/types.h>

#include "cdma.h"

struct cdma_dev {
	char *id;
	char *name;
	int (*get_limit)(struct cdma *ctx, enum cdma_limit what);
	int (*get_time)(struct cdma *ctx, struct cdma_time *ct);
	int (*pin_info)(struct cdma *ctx, int *flags);
	int (*pin_enable)(struct cdma *ctx, const char *pin, int toenable);
	int (*pin_change)(struct cdma *ctx, const char *old, const char *pin);
	int (*pin_enter)(struct cdma *ctx, const char *pin);
	int (*puk_enter)(struct cdma *ctx, const char *puk, const char *pin);
	int (*get_mode)(struct cdma *ctx);
	int (*set_mode)(struct cdma *ctx, int mode);
	int (*sms_send)(struct cdma *ctx, const char *dst, const char *msg,
	    size_t msgsz);
	/* retval: -1 (error), 0 (no sms), 1 (got sms) */
	int (*sms_read)(struct cdma *ctx, struct cdma_sms *sms);
	int (*sms_check)(struct cdma *ctx, u_int *n_sms);
	int (*sms_enum)(struct cdma *ctx, cdma_sms_callback cb);
	int (*sms_delete)(struct cdma *ctx, u_int index);
	int (*sms_save)(struct cdma *ctx, const char *phone,
	    struct cdma_time *ct, const char *msg);
	int (*pb_enum)(struct cdma *ctx, cdma_pb_callback cb);
	int (*pb_add)(struct cdma *ctx, u_int index, const char *phone,
	    const char *name);
	int (*pb_delete)(struct cdma *ctx, u_int index);
};

__BEGIN_DECLS
void			cdma_dev_list(void);
struct cdma_dev *	cdma_dev_id(const char *id);
struct cdma_dev *	cdma_dev_detect(struct cdma *ctx);
__END_DECLS

#endif /* !_CDMA_DEV_H_ */
